.. _filters:

#########
 Filters
#########

Filters can be used to perform data transformations when creating a
dataset. See the :ref:`anemoi-transform
<anemoi-transform:list-of-filters>` documentation for a list of filters
and example configurations.
